@@ -1,25 +1,28 @@
-find_active_file <- function(arg = "file") {
-  if (!rstudioapi::isAvailable()) {
-    stop("Argument `", arg, "` is missing, with no default", call. = FALSE)
+find_active_file <- function(arg = "file", call = parent.frame()) {
+  if (!is_rstudio_running()) {
+    cli::cli_abort("Argument {.arg {arg}} is missing, with no default", call = call)
   }
-  rstudioapi::getSourceEditorContext()$path
+  normalizePath(rstudioapi::getSourceEditorContext()$path)
 }
 
-find_test_file <- function(path) {
+find_test_file <- function(path, call = parent.frame()) {
   type <- test_file_type(path)
   if (any(is.na(type))) {
-    rlang::abort(c(
-      "Don't know how to find tests associated with the active file:",
-      path[is.na(type)]
-    ))
+    file <- path_file(path[is.na(type)])
+    cli::cli_abort(
+      "Don't know how to find tests associated with the active file {.file {file}}",
+      call = call
+    )
   }
 
+  pkg <- as.package(dirname(path))
+
   is_test <- type == "test"
-  path[!is_test] <- paste0("tests/testthat/test-", name_source(path[!is_test]), ".R")
+  path[!is_test] <- paste0(pkg$path, "/tests/testthat/test-", name_source(path[!is_test]), ".R")
   path <- unique(path[file_exists(path)])
 
   if (length(path) == 0) {
-    rlang::abort("No test files found")
+    cli::cli_abort("No test files found", call = call)
   }
   path
 }
