@@ -18,10 +18,10 @@
 #' @param bioconductor If `TRUE` also look for dependencies amongst
 #'   Bioconductor packages.
 #' @param recursive If `TRUE` look for full set of recursive dependencies.
-#' @inheritParams tools::dependsOnPkgs
 #' @seealso The [revdepcheck](https://github.com/r-lib/revdepcheck) package can
 #'  be used to run R CMD check on all reverse dependencies.
 #' @export
+#' @keywords internal
 #' @examples
 #' \dontrun{
 #' revdep("ggplot2")
@@ -63,11 +63,11 @@ print.maintainers <- function(x, ...) {
 
 cran_packages <- memoise::memoise(
   function() {
-    local <- file.path(tempdir(), "packages.rds")
-    utils::download.file("http://cran.R-project.org/web/packages/packages.rds", local,
+    local <- path_temp("packages.rds")
+    utils::download.file("https://cran.R-project.org/web/packages/packages.rds", local,
       mode = "wb", quiet = TRUE
     )
-    on.exit(unlink(local))
+    on.exit(file_delete(local))
     cp <- readRDS(local)
     rownames(cp) <- unname(cp[, 1])
     cp
