@@ -1,7 +1,9 @@
-context("Build Site")
-
 test_that("Package pkgdown site can be built ", {
-  destination <- file.path(tempdir(), "testPkgdown", "docs")
+  # This test requires internet
+  skip_if_offline()
+  skip_on_cran()
+
+  destination <- path(tempdir(), "testPkgdown", "docs")
 
   build_output <- capture.output({
     build_site(
@@ -12,19 +14,19 @@ test_that("Package pkgdown site can be built ", {
 
   build_output <- paste(build_output, collapse = "\n")
 
-  expect_true(file.exists(file.path(destination, "index.html")),
+  expect_true(file_exists(path(destination, "index.html")),
     info = build_output,
     label = "created site index"
   )
-  expect_true(file.exists(file.path(destination, "reference", "index.html")),
+  expect_true(file_exists(path(destination, "reference", "index.html")),
     info = build_output,
     label = "created reference index"
   )
-  expect_true(file.exists(file.path(destination, "articles", "index.html")),
+  expect_true(file_exists(path(destination, "articles", "index.html")),
     info = build_output,
     label = "created articles index"
   )
-  expect_true(file.exists(file.path(destination, "articles", "test.html")),
+  expect_true(file_exists(path(destination, "articles", "test.html")),
     info = build_output,
     label = "created articles index"
   )
